Properties Methods Events Direct Link

# Class Ext.ux.FieldLabeler

Package: | Ext.ux
Defined In: | FieldLabeler.js
Class: | FieldLabeler
Extends: | Object

A plugin for Field Components which renders standard Ext form wrapping and labels round the Field at render time regardless of the layout of the Container.

Usage:

    {
            xtype: 'combo',
            plugins: [ Ext.ux.FieldLabeler ],
            triggerAction: 'all',
            fieldLabel: 'Select type',
            store: typeStore
        }

## Public Properties

This class has no public properties.

## Public Methods

This class has no public methods.

## Public Events

This class has no public events.